# This function is written by Sirus Dehdari (sirus.dehdari@ne.su.se), PhD candidate
# in Economics at Stockholm University.
# Latest version: 7/09/2015

### The function plots the estimates for each bandwidth used in RDD, and adds confidence intervals (default = 90%). It can also be used to just show number of 
### observations for each bandwidth. "fdata" needs to be a $treatment object from the function rddxtab.

rddbandplot <- function(fdata, present = "est", ylab = "Estimate", xlab = "Bandwidth", type = "p", pch = 1, main = "", sub = "", col = 1, lwd = 1, alpha = 0.1, ymax = "d", ymin = "d"){
n <- nrow(fdata)
b <- fdata[,1]
critv <- qt(1-alpha/2,df = 1e9)

if (present == "est"){
  e <- fdata[,2]
  s <- fdata[,3]
  if (ymax == "d"){
  ymax <- max(e + s*critv)
  }
  if (ymin == "d"){
  ymin <- min(e - s*critv)
  }
  plot(b, e, ylim = c(ymin,ymax), ylab = ylab, xlab = xlab, type = type, pch = pch, main = main, sub = sub, col = col)
  abline(0,0)
  for(i in 1:n){
    segments(x0 = b[i], y0 = e[i] - s[i]*critv, y1 = e[i] + s[i]*critv)
    segments(y0 = e[i] + s[i]*critv, x0 = b[i] - 0.20, x1 = b[i] + 0.20)
    segments(y0 = e[i] - s[i]*critv, x0 = b[i] - 0.20, x1 = b[i] + 0.20)
  }
}

if (present == "obs"){
  nobs <- fdata[,6]
  plot(b, nobs, ylab = ylab, xlab = xlab, type = type, pch = pch, main = main, sub = sub, col = col)
  abline(0,0)
for(i in 1:n){
segments(x0 = b[i], y0 = 0, y1 = nobs[i])
}
}
}